//
//  BalloonView.m
//  Auto-Layout
//
//  Created by Clemens Wagner on 29.08.15.
//  Copyright © 2015 Clemens Wagner. All rights reserved.
//

#import "BalloonView.h"
#import "UIView+Geometry.h"

@implementation BalloonView

- (instancetype)init {
    self = [super init];
    if (self) {
        self.translatesAutoresizingMaskIntoConstraints = NO;
        self.backgroundColor = [UIColor clearColor];
    }
    return self;
}

- (UIEdgeInsets)alignmentRectInsets {
    return UIEdgeInsetsMake(0.0, 0.0, self.bottomOffset, 0.0);
}

- (void)drawRect:(CGRect)inRect {
    CGRect theBounds = self.bounds;
    UIEdgeInsets theInsets = [self alignmentRectInsets];
    CGRect theInnerRect = UIEdgeInsetsInsetRect(theBounds, theInsets);
    CGContextRef theContext = UIGraphicsGetCurrentContext();
    CGFloat theTipAngle = self.tipAngle * M_PI / 180.0;
    CGPoint theCenter = CGPointMake(CGRectGetMidX(theInnerRect), CGRectGetMidY(theInnerRect));
    CGPoint theTipPoint = CGPointMake(CGRectGetMinX(theBounds), CGRectGetMaxY(theBounds));
    CGFloat theX = theTipPoint.x - theCenter.x;;
    CGFloat theY = theTipPoint.y - theCenter.y;
    CGFloat theAngle = atan2f(-theY, theX);
    
    if(theAngle < 0) {
        theAngle += 2.0 * M_PI;
    }
    CGContextSaveGState(theContext);
    CGContextSetFillColorWithColor(theContext, [self.tintColor CGColor]);
    CGContextFillEllipseInRect(theContext, theInnerRect);
    CGContextMoveToPoint(theContext, theTipPoint.x, theTipPoint.y);
    theX = theCenter.x + CGRectGetWidth(theInnerRect) * cos(theAngle + theTipAngle) / 2.0;
    theY = theCenter.y - CGRectGetHeight(theInnerRect) * sin(theAngle + theTipAngle) / 2.0;
    CGContextAddLineToPoint(theContext, theX, theY);
    theX = theCenter.x + CGRectGetWidth(theInnerRect) * cos(theAngle - theTipAngle) / 2.0;
    theY = theCenter.y - CGRectGetHeight(theInnerRect) * sin(theAngle - theTipAngle) / 2.0;
    CGContextAddLineToPoint(theContext, theX, theY);
    CGContextClosePath(theContext);
    CGContextFillPath(theContext);
    CGContextRestoreGState(theContext);
}

@end
