//
//  ViewController.m
//  Alignment
//
//  Created by Clemens Wagner on 29.08.15.
//  Copyright © 2015 Clemens Wagner. All rights reserved.
//

#import "ViewController.h"
#import "BalloonView.h"
#import "FolderView.h"

@interface ViewController ()

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    UIView *theView = self.view;
    BalloonView *theBallonView = [BalloonView new];
    FolderView *theFolderView = [FolderView new];
    UIButton *theButton = [UIButton buttonWithType:UIButtonTypeCustom];

    [theView addSubview:theBallonView];
    [theView addSubview:theFolderView];
    [theFolderView addSubview:theButton];
    theBallonView.bottomOffset = 20.0;
    theBallonView.tipAngle = 5.0;
    theBallonView.tintColor = [UIColor colorWithRed:0.0 green:0.85 blue:0.0 alpha:1.0];
    theFolderView.badgeRadius = 16.0;
    theFolderView.cornerRadius = 8.0;
    theFolderView.tintColor = [UIColor orangeColor];
    theButton.translatesAutoresizingMaskIntoConstraints = NO;
    [theButton setTitle:@"2" forState:UIControlStateNormal];
    theButton.backgroundColor = [UIColor redColor];
    [theButton setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
    [theButton setTitleColor:[UIColor blackColor] forState:UIControlStateHighlighted];
    theButton.showsTouchWhenHighlighted = YES;
    theButton.titleLabel.font = [UIFont systemFontOfSize:16.0];
    theButton.layer.cornerRadius = 16.0;
    [theButton addTarget:self action:@selector(badgeTouched:) forControlEvents:UIControlEventTouchUpInside];
    
    // Größe
    // < iOS 9
    [NSLayoutConstraint constraintWithItem:theBallonView attribute:NSLayoutAttributeWidth relatedBy:NSLayoutRelationEqual toItem:nil attribute:NSLayoutAttributeNotAnAttribute multiplier:1.0 constant:120.0].active = YES;
    [NSLayoutConstraint constraintWithItem:theBallonView attribute:NSLayoutAttributeWidth relatedBy:NSLayoutRelationEqual toItem:theBallonView attribute:NSLayoutAttributeHeight multiplier:1.0 constant:0.0].active = YES;
    // ab iOS 9
    [theFolderView.heightAnchor constraintEqualToAnchor:theBallonView.heightAnchor].active = YES;
    [theFolderView.widthAnchor constraintEqualToConstant:150.0].active = YES;
    [theButton.widthAnchor constraintEqualToConstant:32.0].active = YES;
    [theButton.widthAnchor constraintEqualToAnchor:theButton.heightAnchor multiplier:1.0].active = YES;

    // vertikale Ausrichtung
    [theBallonView.centerYAnchor constraintEqualToAnchor:theView.centerYAnchor].active = YES;
    [theFolderView.centerYAnchor constraintEqualToAnchor:theBallonView.centerYAnchor].active = YES;
    [theButton.centerYAnchor constraintEqualToAnchor:theFolderView.topAnchor constant:-16.0].active = YES;
    
    // horizontale Ausrichtung
    [theButton.centerXAnchor constraintEqualToAnchor:theFolderView.trailingAnchor].active = YES;

    UILayoutGuide *theLeftGuide = [UILayoutGuide new];
    UILayoutGuide *theCenterGuide = [UILayoutGuide new];
    UILayoutGuide *theRightGuide = [UILayoutGuide new];
    
    [theView addLayoutGuide:theLeftGuide];
    [theView addLayoutGuide:theCenterGuide];
    [theView addLayoutGuide:theRightGuide];

    [theLeftGuide.widthAnchor constraintEqualToAnchor:theCenterGuide.widthAnchor].active = YES;
    [theLeftGuide.widthAnchor constraintEqualToAnchor:theRightGuide.widthAnchor].active = YES;

    [theView.leadingAnchor constraintEqualToAnchor:theLeftGuide.leadingAnchor].active = YES;
    [theLeftGuide.trailingAnchor constraintEqualToAnchor:theBallonView.leadingAnchor].active = YES;
    [theBallonView.trailingAnchor constraintEqualToAnchor:theCenterGuide.leadingAnchor].active = YES;
    [theCenterGuide.trailingAnchor constraintEqualToAnchor:theFolderView.leadingAnchor].active = YES;
    [theFolderView.trailingAnchor constraintEqualToAnchor:theRightGuide.leadingAnchor].active = YES;
    [theRightGuide.trailingAnchor constraintEqualToAnchor:theView.trailingAnchor].active = YES;
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (IBAction)badgeTouched:(id)inSender {
    NSLog(@"Badge touched");
}

@end